DeviceVolumeBindings class

Bindings for src/device_volume.h.

Regenerate bindings with dart run ffigen --config ffigen.yaml.

Constructors

DeviceVolumeBindings(DynamicLibrary dynamicLibrary)
The symbols are looked up in dynamicLibrary.
DeviceVolumeBindings.fromLookup(Pointer<T> lookup<T extends NativeType>(String symbolName))
The symbols are looked up with lookup.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

device_volume_decrement(int channel, int show_system_ui) DeviceVolumeResult
device_volume_get(int channel) DeviceVolumeResult
── Public API ──────────────────────────────────────────────────────────────
device_volume_increment(int channel, int show_system_ui) DeviceVolumeResult
device_volume_set(int channel, int value, int show_system_ui) DeviceVolumeResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited